#! /bin/sh
#Name:          os_install.sh
#Author:		David Dumke
#DateCreated:	Feb 15, 2011
#LastModified:  Oct 18, 2010
#Version:		1.4

# DEFINES
#
#0x3c0000 - 3932160, 0x780000 - 7864320
#NAND ATAGS are on mtd3, INITRD ATAGS are on mtd2

echo ""
echo "*************************************"
echo "*          os_install.sh            *"
echo "*************************************"
echo ""

usb_drive=$1
ARMRFS=VSARMRFS.tgz
APPFILE=VSARMAPP.tgz

echo "USB path " $usb_drive

cd $usb_drive
. $usb_drive/topline.sh

#                      12345678901234567890
sleep 1
./progmsg t 25 "$topline OS prep ...       "
sleep 1


if [ -e "/dev/mtd3 $usb_drive/$ARMRFS" ]
then
	echo "ERROR! - Missing OS and file system image, $ARMRFS"
	sleep 1
	#                      12345678901234567890
	./progmsg t 28 "$topline Missing OS file  "
	sleep 1
	exit
fi
if [ -e "/dev/mtd3 $usb_drive/$APPFILE" ]
then
	echo "ERROR! - Missing application image, $APPFILE"
	sleep 1
	#                      12345678901234567890
	./progmsg t 28 "$topline Missing AAP file  "
	sleep 1
	exit
fi

sleep 1
#                      12345678901234567890
./progmsg t 28 "$topline Erasing flash ...       "
sleep 1
echo "Erase flash partition mtd5(application)"
flash_eraseall /dev/mtd4
flash_eraseall /dev/mtd5

#                      12345678901234567890
./progmsg t 30 "$topline Create UBI fs ...  "
echo "Volume info..."
cat /proc/mtd
echo "Create and attach file systems"
#Create ubi0 and ubi1 nodes
ubiattach /dev/ubi_ctrl -m 4 -d 0
sleep 1
ubiattach /dev/ubi_ctrl -m 5 -d 1
sleep 1
#Create create linux and application volumes
ubimkvol /dev/ubi0 -m -N linux
sleep 1
ubimkvol /dev/ubi1 -m -N application
sleep 1
#Make directories and mount the volumes
mkdir /linux
mkdir /application
mount -o sync -t ubifs ubi0:linux /linux
sleep 1
mount -o sync -t ubifs ubi1:application /application
sleep 1
echo "Extracting OS onto /linux ..."
#tar -C /linux -xzf $usb_drive/$ARMRFS

#                         12345678901234567890
sleep 1
./progmsg t 31/79 "$topline Installing OS ...  " $usb_drive/$ARMRFS /linux
sleep 1

echo "Extracting applications onto /nautel ..."
cd $usb_drive
#tar -C /application -xzf $usb_drive/$APPFILE
sleep 1
#                         12345678901234567890
./progmsg t 80/95 "$topline Installing APP ... " $usb_drive/$APPFILE /application
sleep 1
./progmsg t 95 "$topline APP complete ...   "
sleep 1

rm -f /linux/chpasswd.scr


sync

# imprint install details into base OS version
cd $usb_drive
tail *.version >> install.ver
# extract < > to avoid XML errors
sed -i 's/>//g' install.ver
sed -i 's/<//g' install.ver

cd /application
sed -i 's/<\/OS>/<install>/' base_os.ver
cat /mnt/usb/install.ver >> base_os.ver
echo "</install>" >> base_os.ver
echo "</OS>" >> base_os.ver


cd $usb_drive

umount /application
umount /linux
#                        1234567890123456789012345678901234567890
sleep 1
./progmsg t 100 "$topline Please cycle AC   and install AUI SW"

#./progmsg t 100 "$topline OS Install complete Rebooting in 20s   "
#sleep 20
#cat reboot_arm.bin > /dev/ttyS0
cd /

echo ""
echo "OS installation complete."
echo ""

