
#Author:        David Dumke
#DateCreated:   Feb 11, 2010
#LastModified:  Oct 18, 2010
#Version:      	1.7
#
#
# Log Version 1.7
#   - Index will now return 0 when no bad blocks were found.
#		- zImage is now padded out to 30 blocks and is called zImage_padded.
#   - createtags is no longer called. Instead the ATAGS are parsed from the fallback system
# DEFINES
#
# PAS Jul 25 2013: Adapted for VSARM 4.0
#
#0x3c0000 - 3932160, 0x780000 - 7864320
#NAND ATAGS are on mtd3, INITRD ATAGS are on mtd2

usb_drive=$1

echo ""
echo "*************************************"
echo "*           sys_install.sh          *"
echo "*************************************"
echo ""

cd $usb_drive

tail *.version

cd $usb_drive
. $usb_drive/topline.sh


#                      12345678901234567890
sleep 1
./progmsg t 2 "$topline Starting ...       "
sleep 1


# ensure all files and executables required are present on the USB drive

REQFILES="createtags
zImage_current.version
zImage_padded_current
os_install.sh
sys_install.sh
bootloader_stage2.bin
bootloader_stage2.version
progmsg"

#Check we have the necessary files
for file in $REQFILES
do
	if [ -e "$usb_drive/$file" ]
	then
		echo "found $file"
	else
		echo "ERROR! - missing file $file"
		sleep 1
		./progmsg t 20 "$topline ERROR: missing install file on USB"
		while [ 1 ]; do sleep 1; done
	fi
done


echo ""
echo "*************************************"
echo "*           Parse MAC Address       *"
echo "*************************************"
echo ""
sleep 1
./progmsg t 4 "$topline Detect MAC address"
sleep 1
index=0
block_size=131072
start_addr_mtd2_ramdisk=3932160
start_addr_initrd_atags=7864320
start_addr_nand_atags=3932160
start_addr=0


#
# Extract the fallback ATAGs in order to get to the MAC
#
FINISHED=1
NOT_FINISHED=0

tagFound=$NOT_FINISHED
start_addr=$start_addr_initrd_atags
while [ "$tagFound" != "$FINISHED" ]
do
	let start_addr=$start_addr_initrd_atags+$index\*$block_size
	echo "Test Addr: [$start_addr]"
	nanddump -s $start_addr -l 1 -p -f tag_dump.bin /dev/mtd2
	tagFound=$( cat tag_dump.bin | sed -n "s/.*0000: 05 00 00 00 01 00 41 54 00 00 00 00 00 00 00 00.*/$FINISHED/p")
	
	let index+=1
	if [ $index -gt 10 ]
	then
		echo "!! ERROR: No MAC address found ... exiting."
		sleep 1
#                              12345678901234567890
		./progmsg t 5 "$topline ERROR: No MAC found"

		while [ 1 ]; do sleep 1; done
	fi
done

macAddress=$(cat tag_dump.bin | sed -n "s/0x00..0090: \(00\) \(00\) \([0-9a-fA-F]\+\) \([0-9a-fA-F]\+\) \([0-9a-fA-F]\+\) \([0-9a-fA-F]\+\) \([0-9a-fA-F]\+\) \([0-9a-fA-F]\+\).*/\3\4\5\6\7\8/p")
echo "Found MAC generating new ATAGS."
echo "$macAddress" | ./createtags



echo ""
echo "*************************************"
echo "*     Install Stage2 Bootloader     *"
echo "*************************************"
echo ""
sleep 1
#                       12345678901234567890
./progmsg t 6 "$topline S2 Bootloader      "
sleep 1
nandtest -m /dev/mtd1
flash_eraseall /dev/mtd1
nandwrite -p -s 0 /dev/mtd1 $usb_drive/bootloader_stage2.bin


echo ""
echo "*************************************"
echo "*       Install System Kernel       *"
echo "*************************************"
echo ""
index=0
totalBBC=0
echo "USB path " $usb_drive
sleep 1
#                       12345678901234567890
./progmsg t 10 "$topline Kernel preparation "
sleep 1


echo "Erase flash partition mtd3"
nandtest -m /dev/mtd3
flash_eraseall /dev/mtd3

cd $usb_drive

echo "Creating install image"
cat zImage_padded_current nand.tag > current.bin
#                       12345678901234567890
./progmsg t 15 "$topline Kernel Install     "
nandwrite -p -s 0 /dev/mtd3 current.bin
rm current.bin
sync
sleep 1
#                       12345678901234567890
./progmsg t 24 "$topline Kernel complete    "
sleep 1
echo "finished writing runtime kernel"




